@@ -5,16 +5,6 @@ import objc
 from PyObjCTools.TestSupport import *
 from DictionaryServices import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
-try:
-    long
-except NameError:
-    long = int
-
 class TestDictionaryServices (TestCase):
     def testClasses(self):
         self.assertIsCFType(DCSDictionaryRef)
@@ -30,7 +20,7 @@ class TestDictionaryServices (TestCase):
         self.assertIsInstance(r, (unicode, type(None)))
 
         v = DCSDictionaryGetTypeID()
-        self.assertIsInstance(v, (int, long))
+        self.assertIsInstance(v, (int, long))     
 
 
 if __name__ == "__main__":
